R/data_Great_South_Channel_Restricted_Trap_Pot_Area.R
Great_South_Channel_Restricted_Trap_Pot_Area.RdAn sf object that depicts the boundaries of the Great South Channel Restricted Area in effect from April 1 to June 30 annually for the NOAA Fisheries Service’s Greater Atlantic Regional Fisheries Office (GARFO).
data("Great_South_Channel_Restricted_Trap_Pot_Area")An sf object:
POLYGON
XY
xmin: -69.75 ymin: 41 xmax: -68.21667 ymax: 42.16667
NAD83
1 x 26
See source
if (FALSE) { # \dontrun{
# Load the dataset
data(Great_South_Channel_Restricted_Trap_Pot_Area)
# Plot the geometry
plot(sf::st_geometry(Great_South_Channel_Restricted_Trap_Pot_Area))
} # }