An sf object that depicts the boundaries of the Lobster Management Area One Restricted Area in effect annually from October 1 to January 30 for the NOAA Fisheries Service’s Greater Atlantic Regional Fisheries Office (GARFO).
data("LMA1_Restricted_Area_FR")An sf object:
POLYGON
XY
xmin: -69.6128 ymin: 42.89198 xmax: -68.28787 ymax: 43.73333
WGS 84
1 x 26
See source
if (FALSE) { # \dontrun{
# Load the dataset
data(LMA1_Restricted_Area_FR)
# Plot the geometry
plot(sf::st_geometry(LMA1_Restricted_Area_FR))
} # }