An sf object containing the box level boundaries used in the Northeast Atlantis ecosystem end to end model.
data("Neus_atlantis")An sf object:
POLYGON
XY
xmin: -76.45919 ymin: 34.76128 xmax: -63.42171 ymax: 46.11478
WGS 83
30 x 11
See source
if (FALSE) { # \dontrun{
# Load the dataset
data(Neus_atlantis)
# Plot the geometry
plot(sf::st_geometry(Neus_atlantis))
} # }