An sf object containing spatial data for the Coastal Shark Bottom Longline Survey. Sampling stations for the Coastal Shark Bottom Longline Survey.
data('csbll_stations')An sf object:
POINT
NA
xmin: -81.6 ymin: 24.5 xmax: -74.5 ymax: 38.4
WGS 84
87 x 6
See source
https://mdeb-nefsc-noaa.hub.arcgis.com/
if (FALSE) { # \dontrun{
# Load the dataset
data(csbll_stations)
# Plot the geometry
plot(sf::st_geometry(csbll_stations))
} # }