An sf object containing spatial data for the Coastal Shark Bottom Longline Survey. Scientific survey strata for the Coastal Shark Bottom Longline Survey.
data('csbll_strata')An sf object:
MULTIPOLYGON
XY
xmin: -81.7 ymin: 24.4 xmax: -74.4 ymax: 38.5
WGS 84
1 x 5
See source
https://mdeb-nefsc-noaa.hub.arcgis.com/
if (FALSE) { # \dontrun{
# Load the dataset
data(csbll_strata)
# Plot the geometry
plot(sf::st_geometry(csbll_strata))
} # }