An sf object containing spatial data for the Gulf of Maine Bottom Longline Survey. Scientific survey strata for the Gulf of Maine Bottom Longline Survey.
data('gombll_strata')An sf object:
POLYGON
XY
xmin: -70.7 ymin: 42 xmax: -67.4 ymax: 43.4
WGS 84
6 x 9
See source
https://mdeb-nefsc-noaa.hub.arcgis.com/
if (FALSE) { # \dontrun{
# Load the dataset
data(gombll_strata)
# Plot the geometry
plot(sf::st_geometry(gombll_strata))
} # }