An sf object containing spatial data for the Gulf of Maine Bottom Longline Survey. Scientific survey substrata for the Gulf of Maine Bottom Longline Survey. The survey substrata give further details on bottom-type (smooth or rough bottom) encountered in the survey area.
data('gombll_substrata')An sf object:
MULTIPOLYGON
XY
xmin: -70.7 ymin: 42 xmax: -67.4 ymax: 43.4
WGS 84
12 x 14
See source
https://mdeb-nefsc-noaa.hub.arcgis.com/
if (FALSE) { # \dontrun{
# Load the dataset
data(gombll_substrata)
# Plot the geometry
plot(sf::st_geometry(gombll_substrata))
} # }