An sf object containing spatial data for the Massachusetts Inshore State Survey.
data('mass_inshore_strata')An sf object:
MULTIPOLYGON
XY
xmin: 231326.1 ymin: 772098.2 xmax: 336448.2 ymax: 958709
NAD83 / Massachusetts Mainland
42 x 8
See source
https://www.mass.gov/info-details/review-trawl-survey-updates. Division of Marine Fisheries - New Bedford Office. For more info contact the Resource Assessment Project Leader.
if (FALSE) { # \dontrun{
# Load the dataset
data(mass_inshore_strata)
# Plot the geometry
plot(sf::st_geometry(mass_inshore_strata))
} # }