An sf object containing spatial data for the North Atlantic Right Whale Aerial Survey. Aerial survey lines for the North Atlantic Right Whale Aerial Survey.
data('narw_lines')An sf object:
MULTILINESTRING
NA
xmin: -76 ymin: 36.7 xmax: -66.9 ymax: 44.8
WGS 84
80 x 6
See source
https://mdeb-nefsc-noaa.hub.arcgis.com/
if (FALSE) { # \dontrun{
# Load the dataset
data(narw_lines)
# Plot the geometry
plot(sf::st_geometry(narw_lines))
} # }