An sf object containing spatial data for the North Atlantic Right Whale Aerial Survey. Scientific survey strata for the North Atlantic Right Whale Aerial Survey.
data('narw_strata')An sf object:
MULTIPOLYGON
XY
xmin: -76 ymin: 36.7 xmax: -66.9 ymax: 44.8
WGS 84
1 x 5
See source
https://mdeb-nefsc-noaa.hub.arcgis.com/
if (FALSE) { # \dontrun{
# Load the dataset
data(narw_strata)
# Plot the geometry
plot(sf::st_geometry(narw_strata))
} # }