An sf object containing spatial data for the Sea Scallop Survey. The current (as of 2025) NEFSC Scallop Strata (SAMS). Starting in 2025, a spatially balanced form of stratified random sampling called Generalized Random Tessellation Stratified (GRTS) was implemented, along with a switch to using Scallop Area Management Simulator (SAMS) areas as survey strata. While still a form of stratified random sampling, this method prevents random stations from being placed very close together. Use of the SAMS areas as strata ensures that sampling is more useful to management.
data('scallop_strata')An sf object:
POLYGON
XY
xmin: -74.9 ymin: 36.6 xmax: -66.3 ymax: 42.2
WGS 84
23 x 8
See source
https://mdeb-nefsc-noaa.hub.arcgis.com/
if (FALSE) { # \dontrun{
# Load the dataset
data(scallop_strata)
# Plot the geometry
plot(sf::st_geometry(scallop_strata))
} # }